@@ -96,27 +96,34 @@ class JobLock(object):
       self.__open()
     except FileExistsError:
       if self.__message is jobinfo:
-        try:
-          oldjobinfo = self.runningjobinfo(exceptions=True)
-        except (IOError, OSError):
+        #check if the job died without removing the lock
+        #however this needs another job lock, because it has
+        #a race condition: two jobs could be looking if the previous
+        #job failed at the same time, and one of them could remove
+        #the lock created by the other one
+        with JobLock(self.filename.with_suffix(self.filename.suffix+".lock")) as iterative_lock:
+          if not iterative_lock: return None
           try:
-            self.__open()
-          except FileExistsError:
-            return None
-        except ValueError:
-          return None
-        else:
-          if jobfinished(*oldjobinfo):
-            for outputfile in self.outputfiles:
-              rm_missing_ok(outputfile)
-            rm_missing_ok(self.filename)
-            removed_failed_job = True
+            oldjobinfo = self.runningjobinfo(exceptions=True)
+          except (IOError, OSError):
             try:
               self.__open()
             except FileExistsError:
               return None
-          else:
+          except ValueError:
             return None
+          else:
+            if jobfinished(*oldjobinfo):
+              for outputfile in self.outputfiles:
+                rm_missing_ok(outputfile)
+              rm_missing_ok(self.filename)
+              removed_failed_job = True
+              try:
+                self.__open()
+              except FileExistsError:
+                return None
+            else:
+              return None
       else:
         return None
 
